from typing import Literal

Skew = Literal[
    'x-0',
    'y-0',
    'x-1',
    'y-1',
    'x-2',
    'y-2',
    'x-3',
    'y-3',
    'x-6',
    'y-6',
    'x-12',
    'y-12',
]
